==> helper-8.x-1.35.tar.gz: helper/docs/api/ArrayHelper.md <==
# Drupal\helper\ArrayHelper  

Provides helper for working with arrays.





## Methods

| Name | Description |
|------|-------------|
|[addUniqueValue](#arrayhelperadduniquevalue)|Add a value to an array if it is not already present.|
|[chunkEvenly](#arrayhelperchunkevenly)|Split an array into chunks more evenly then array_chunk().|
|[filterKeys](#arrayhelperfilterkeys)|Filters keys of an array using a callback function.|
|[hasValue](#arrayhelperhasvalue)|Checks if an array contains a value.|
|[mapKeys](#arrayhelpermapkeys)|Applies the callback to the keys of the given array.|
|[removeValue](#arrayhelperremovevalue)|Remove an array's value.|
|[replaceKey](#arrayhelperreplacekey)|Replace array key.|
|[replaceKeys](#arrayhelperreplacekeys)|Replace array keys.|
|[replaceValue](#arrayhelperreplacevalue)|Replace array value.|
|[replaceValues](#arrayhelperreplacevalues)|Replace multiple array values.|




### ArrayHelper::addUniqueValue  

**Description**

```php
public static addUniqueValue (array $array, mixed $value, mixed|null $key, bool $strict)
```

Add a value to an array if it is not already present. 

 

**Parameters**

* `(array) $array`
* `(mixed) $value`
* `(mixed|null) $key`
* `(bool) $strict`

**Return Values**

`bool`




<hr />


### ArrayHelper::chunkEvenly  

**Description**

```php
public static chunkEvenly (array $array, int $chunks, bool $preserve_keys)
```

Split an array into chunks more evenly then array_chunk(). 

 

**Parameters**

* `(array) $array`
* `(int) $chunks`
* `(bool) $preserve_keys`

**Return Values**

`array`




**Throws Exceptions**


`\DomainException`


<hr />


### ArrayHelper::filterKeys  

**Description**

```php
public static filterKeys (array $array, callable $callback)
```

Filters keys of an array using a callback function. 

 

**Parameters**

* `(array) $array`
* `(callable) $callback`

**Return Values**

`array`




<hr />


### ArrayHelper::hasValue  

**Description**

```php
public static hasValue (array $array, mixed $value, bool $strict, array|null $keys)
```

Checks if an array contains a value. 

 

**Parameters**

* `(array) $array`
* `(mixed) $value`
* `(bool) $strict`
* `(array|null) $keys`

**Return Values**

`bool`




<hr />


### ArrayHelper::mapKeys  

**Description**

```php
public static mapKeys (array $array, callable $callback)
```

Applies the callback to the keys of the given array. 

 

**Parameters**

* `(array) $array`
* `(callable) $callback`

**Return Values**

`array`




<hr />


### ArrayHelper::removeValue  

**Description**

```php
public static removeValue (array $array, mixed $value, bool $strict)
```

Remove an array's value. 

 

**Parameters**

* `(array) $array`
* `(mixed) $value`
* `(bool) $strict`

**Return Values**

`bool`




<hr />


### ArrayHelper::replaceKey  

**Description**

```php
public static replaceKey (array $array, mixed $search, mixed $replace, bool $strict)
```

Replace array key. 

 

**Parameters**

* `(array) $array`
* `(mixed) $search`
* `(mixed) $replace`
* `(bool) $strict`

**Return Values**

`void`


<hr />


### ArrayHelper::replaceKeys  

**Description**

```php
public static replaceKeys (array $array, array $replacements, bool $strict)
```

Replace array keys. 

 

**Parameters**

* `(array) $array`
* `(array) $replacements`
* `(bool) $strict`

**Return Values**

`void`


<hr />


### ArrayHelper::replaceValue  

**Description**

```php
public static replaceValue (array $array, mixed $search, mixed $replace, bool $strict)
```

Replace array value. 

 

**Parameters**

* `(array) $array`
* `(mixed) $search`
* `(mixed) $replace`
* `(bool) $strict`

**Return Values**

`void`


<hr />


### ArrayHelper::replaceValues  

**Description**

```php
public static replaceValues (array $array, array $replacements, bool $strict)
```

Replace multiple array values. 

 

**Parameters**

* `(array) $array`
* `(array) $replacements`
* `(bool) $strict`

**Return Values**

`void`


<hr />

==> helper-8.x-1.36.tar.gz: helper/docs/api/ArrayHelper.md <==
# Drupal\helper\ArrayHelper  

Provides helper for working with arrays.





## Methods

| Name | Description |
|------|-------------|
|[addUniqueValue](#arrayhelperadduniquevalue)|Add a value to an array if it is not already present.|
|[chunkEvenly](#arrayhelperchunkevenly)|Split an array into chunks more evenly then array_chunk().|
|[filterKeys](#arrayhelperfilterkeys)|Filters keys of an array using a callback function.|
|[hasValue](#arrayhelperhasvalue)|Checks if an array contains a value.|
|[mapKeys](#arrayhelpermapkeys)|Applies the callback to the keys of the given array.|
|[removeValue](#arrayhelperremovevalue)|Remove an array's value.|
|[replaceKey](#arrayhelperreplacekey)|Replace array key.|
|[replaceKeys](#arrayhelperreplacekeys)|Replace array keys.|
|[replaceValue](#arrayhelperreplacevalue)|Replace array value.|
|[replaceValues](#arrayhelperreplacevalues)|Replace multiple array values.|




### ArrayHelper::addUniqueValue  

**Description**

```php
public static addUniqueValue (array $array, mixed $value, mixed|null $key, bool $strict)
```

Add a value to an array if it is not already present. 

 

**Parameters**

* `(array) $array`
* `(mixed) $value`
* `(mixed|null) $key`
* `(bool) $strict`

**Return Values**

`bool`




<hr />


### ArrayHelper::chunkEvenly  

**Description**

```php
public static chunkEvenly (array $array, int $chunks, bool $preserve_keys)
```

Split an array into chunks more evenly then array_chunk(). 

 

**Parameters**

* `(array) $array`
* `(int) $chunks`
* `(bool) $preserve_keys`

**Return Values**

`array`




**Throws Exceptions**


`\DomainException`


<hr />


### ArrayHelper::filterKeys  

**Description**

```php
public static filterKeys (array $array, callable|null $callback)
```

Filters keys of an array using a callback function. 

 

**Parameters**

* `(array) $array`
* `(callable|null) $callback`

**Return Values**

`array`




<hr />


### ArrayHelper::hasValue  

**Description**

```php
public static hasValue (array $array, mixed $value, bool $strict, array|null $keys)
```

Checks if an array contains a value. 

 

**Parameters**

* `(array) $array`
* `(mixed) $value`
* `(bool) $strict`
* `(array|null) $keys`

**Return Values**

`bool`




<hr />


### ArrayHelper::mapKeys  

**Description**

```php
public static mapKeys (array $array, callable $callback)
```

Applies the callback to the keys of the given array. 

 

**Parameters**

* `(array) $array`
* `(callable) $callback`

**Return Values**

`array`




<hr />


### ArrayHelper::removeValue  

**Description**

```php
public static removeValue (array $array, mixed $value, bool $strict)
```

Remove an array's value. 

 

**Parameters**

* `(array) $array`
* `(mixed) $value`
* `(bool) $strict`

**Return Values**

`bool`




<hr />


### ArrayHelper::replaceKey  

**Description**

```php
public static replaceKey (array $array, mixed $search, mixed $replace, bool $strict)
```

Replace array key. 

 

**Parameters**

* `(array) $array`
* `(mixed) $search`
* `(mixed) $replace`
* `(bool) $strict`

**Return Values**

`void`


<hr />


### ArrayHelper::replaceKeys  

**Description**

```php
public static replaceKeys (array $array, array $replacements, bool $strict)
```

Replace array keys. 

 

**Parameters**

* `(array) $array`
* `(array) $replacements`
* `(bool) $strict`

**Return Values**

`void`


<hr />


### ArrayHelper::replaceValue  

**Description**

```php
public static replaceValue (array $array, mixed $search, mixed $replace, bool $strict)
```

Replace array value. 

 

**Parameters**

* `(array) $array`
* `(mixed) $search`
* `(mixed) $replace`
* `(bool) $strict`

**Return Values**

`void`


<hr />


### ArrayHelper::replaceValues  

**Description**

```php
public static replaceValues (array $array, array $replacements, bool $strict)
```

Replace multiple array values. 

 

**Parameters**

* `(array) $array`
* `(array) $replacements`
* `(bool) $strict`

**Return Values**

`void`


<hr />
